==> haskell-stm-hamt-1.2.1.1-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-8nCNyBqOe9m8ubGJputdvt
key:                  stm-hamt-1.2.1.1-8nCNyBqOe9m8ubGJputdvt
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  180b80473fac6689bf40b88074ad83dd
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-8nCNyBqOe9m8ubGJputdvt
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-C8YguoMEwBsD5engKreTsc
    focus-1.0.3.2-EgafqfI18jKLjVGmA0bewF
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    list-t-1.0.5.7-6HMu2twXA5zBkE80tr321F
    primitive-0.9.1.0-8f7NBHiHFdgFE3qTf44BEn
    primitive-extras-0.10.2.2-4Gd10Xlzm8O6t1Z32zXOTb
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.1.1-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.1.1
visibility:           public
id:                   stm-hamt-1.2.1.1-DnXIonphStS86ccdoEeSJs
key:                  stm-hamt-1.2.1.1-DnXIonphStS86ccdoEeSJs
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  e869be21b795f06c4ba935ae98b28547
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-hamt-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1.1-DnXIonphStS86ccdoEeSJs
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-9U8wQFwf5Gb1nmAAoCEigd
    focus-1.0.3.2-GEQodUkzm5XChxmnluWh1h
    hashable-1.4.7.0-bh6X3bZPF56LQTYQ27khw
    list-t-1.0.5.7-BcF8aibxttT5JeppZS72xW
    primitive-0.9.1.0-BeRIw0AUz65FDgv1GzpeGd
    primitive-extras-0.10.2.2-2oKm75NOCZC6dnIZ2TR10P
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
